@@ -52,9 +52,8 @@ deprecated:
 * Methods C<getElevation()> and C<getAllElevations()>. The
 C<elevation()> method will remain.
 
-Starting with release [% next_version %], all deprecated functionality will warn
-the first time it is used. Six months after that release, it will warn
-every time it is used, and six months after that it will become fatal.
+Starting with release 0.104_01, all deprecated functionality will warn
+every time it is used. Six months after that it will become fatal.
 After a further six months, all code related to the deprecated
 functionality will be removed.
 
@@ -118,7 +117,7 @@ use JSON;
 use LWP::UserAgent;
 use Scalar::Util 1.10 qw{ blessed looks_like_number };
 
-our $VERSION = '0.103';
+our $VERSION = '0.105';
 
 use constant BEST_DATA_SET => -1;
 use constant USGS_URL => 'http://nationalmap.gov/epqs/pqs.php';
@@ -140,12 +139,16 @@ my $using_time_hires;
 
     $mark = _time();
     sub _pause {
-	my ( $self ) = @_;
+##	my ( $self ) = @_;	# Invocant unused
 	my $now = _time();
 	while ( $now < $mark ) {
 	    _sleep( $mark - $now );
 	    $now = _time();
 	}
+	# We use __PACKAGE__ rather than $self because the attribute is
+	# static, and it needs to be static because it needs to apply to
+	# everything coming from this user, not just everything coming
+	# from the invoking object.
 	$mark = $now + __PACKAGE__->get( 'throttle' );
 	return;
     }
@@ -473,10 +476,10 @@ sub _set_unsigned_integer {
 	attribute	=> {
 	    dflt	=> sub { return },
 	    item	=> {
-		default_ns	=> 1,
-		proxy		=> 1,
-		source		=> 1,
-		use_all_limit	=> 1,
+		default_ns	=> 2,
+		proxy		=> 2,
+		source		=> 2,
+		use_all_limit	=> 2,
 	    },
 	},
 	subroutine	=> {
@@ -485,8 +488,8 @@ sub _set_unsigned_integer {
 		return $name;
 	    },
 	    item	=> {
-		getElevation		=> 1,
-		getAllElevations	=> 1,
+		getElevation		=> 2,
+		getAllElevations	=> 2,
 	    },
 	},
     );
@@ -957,7 +960,7 @@ Thomas R. Wyant, III; F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2015 Thomas R. Wyant, III
+Copyright (C) 2008-2016 Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
